function [gamma,frequency] = vna_port1(obj,file)
%VNA_PORT1 Reflexionsfaktoren unkalibriert an Tor 1 messen
%   Kommunikation erfolgt mit SCPI-Befehlen
%   input arguments
%       obj             Instrument Object
%       file            Dateiname
%   output arguments
%       gamma           komplexwertige Reflexionsfaktoren
%       frequency       Messfrequenzen
%
%   Instrument Control Toolbox 
%       S. 1-23 bis 1-24
%       S. 3-19 bis 3-24
%
%   R&S ZVL Vector Network Analyzer Operating Manual
%       Start of the Measurement and Command Synchronization, S.559
%
%   SCPI-Befehle 
%       CALCulate<Ch>:PARameter:SDEFine '<string>', 'S11' | ... | 'Y-S11' | ... | 'Z-S11' | ...
%       [SENSe<Ch>:]CORRection[:STATe] <Boolean>
%       INITiate<Ch>[:IMMediate]
%       *WAI
%       CALCulate<Chn>:DATA:STIMulus?
%       [SENSe<Ch>:]FREQuency:STARt <start_frequency>
%       [SENSe<Ch>:]FREQuency:STOP <stop_frequency>
%       [SENSe<Ch>:]SWEep:POINts <no_points>
%       CALCulate<Chn>:DATA SDATa, <data>
%       MEASurement<n>:FORMat <Format>
%       TRACe[:DATA]?
%       CALCulate<Ch>:PARameter:DELete '<string>'
%
%   28.08.2019          T. Weber    
%   29.11.2020          Untersttzung fr FPC1500 hinzugefgt

switch obj.Name
    case 'none'
        % Messwerte aus Datei lesen
        data = load(file,'-ascii');
        frequency = data(:,1);
        gamma = data(:,2)+j*data(:,3);
        
    case {'zvl','znle','zvb'}
        % Trace erzeugen und zu messenden Streuparameter einstellen
        fprintf(obj,'CALC1:PAR:SDEF ''Trc11'',''S11''');

        % Kalibrierung abschalten
        fprintf(obj,'CORR 0');

        % einen Sweep ausfhren
        fprintf(obj,'INIT1');
        fprintf(obj,'*WAI');

        % Stimulus auslesen, kommaseparierte Liste mit scanstr parsen
        fprintf(obj,'CALC1:DATA:STIM?');
        frequency = scanstr(obj,',','%f');

        % Trace auslesen, kommaseparierte Liste mit scanstr parsen
        fprintf(obj,'CALC1:DATA? SDAT');
        raw_data = scanstr(obj,',','%f');

        % aus Real- und Imaginrteilen komplexe Reflexionsfaktoren berechnen
        gamma = raw_data(1:2:numel(raw_data)-1)+j*raw_data(2:2:numel(raw_data));
        
        % Messwerte in Datei schreiben
        data = [frequency,real(gamma),imag(gamma)];
        save(file,'data','-ascii');
        
        % den Trace wieder lschen
        fprintf(obj,'CALC1:PAR:DEL ''Trc11''');
        
    case 'fpc'
        % einen Sweep ausfhren
        fprintf(obj,'INIT');
        fprintf(obj,'*WAI');
        
        % Stimulus rekonstruieren
        fprintf(obj,'FREQ:STAR?');
        fstart = fscanf(obj,'%f');
        fprintf(obj,'FREQ:STOP?');
        fstop = fscanf(obj,'%f');
        fprintf(obj,'SWE:POIN?');
        n = fscanf(obj,'%d');
        frequency = linspace(fstart,fstop,n)';

        % Betragsmessung aktivieren
        fprintf(obj,'MEAS:FORM MAGN');
        
        % Trace auslesen, kommaseparierte Liste mit scanstr parsen
        fprintf(obj,'TRAC?');
        magnitude = scanstr(obj,',','%f');

        % Phasenmessung aktivieren
        fprintf(obj,'MEAS:FORM PHAS');

        % Trace auslesen, kommaseparierte Liste mit scanstr parsen
        fprintf(obj,'TRAC?');
        phase = scanstr(obj,',','%f');

        % aus Betrag und Phase komplexe Reflexionsfaktoren berechnen
        gamma = 10.^(magnitude/20).*exp(j*phase*pi/180);
        
        % Messwerte in Datei schreiben
        data = [frequency,real(gamma),imag(gamma)];
        save(file,'data','-ascii');
        
    otherwise
    	error('unsupported VNA');
        
end

end
